import { MastraBase } from './chunk-27EL4TRB.js';
import { __name, __publicField } from './chunk-AJJZUHB4.js';
import dotenv from 'dotenv';
import { readFileSync, existsSync } from 'fs';
import { join } from 'path';

var _MastraDeployer = class _MastraDeployer extends MastraBase {
  constructor({ scope, env, projectName }) {
    super({
      component: "DEPLOYER",
      name: "MasterDeployer"
    });
    __publicField(this, "scope");
    __publicField(this, "projectName");
    __publicField(this, "env");
    this.scope = scope;
    this.env = env;
    this.projectName = projectName;
  }
  loadEnvVars() {
    this.logger.debug("Loading environment variables into context.");
    this.getEnvFiles().forEach((file) => {
      const content = readFileSync(file, "utf-8");
      const config = dotenv.parse(content);
      this.env = {
        ...this.env,
        ...config
      };
    });
  }
  getEnvFiles() {
    this.logger.debug("Reading environment variables from .env or .env.production files.");
    const envFiles = [
      ".env",
      ".env.production"
    ].map((file) => join(process.cwd(), file)).filter((file) => existsSync(file));
    return envFiles;
  }
  parseEnvFile(filePath) {
    this.logger.debug(`Parsing environment variables file: ${filePath}`);
    const content = readFileSync(filePath, "utf-8");
    return content.split("\n").map((line) => line.trim()).filter((line) => line && !line.startsWith("#")).filter((line) => line.includes("="));
  }
  writeFiles({ dir }) {
    this.logger.debug(`Writing files to ${dir}`);
  }
  writeIndex({ dir }) {
    this.logger.debug(`Writing index file to ${dir}`);
  }
  async deploy({ dir, siteId }) {
    this.logger.debug(`Deploying with command ${this.scope}...${siteId || ""} to ${dir} ${this.projectName || "mastra-starter"}`);
  }
};
__name(_MastraDeployer, "MastraDeployer");
var MastraDeployer = _MastraDeployer;

export { MastraDeployer };
